pub struct DamagedFile {
pub filename: String,
pub size: u64,
pub damaged_block_count: u32,
pub total_block_count: u32,
pub damaged_block_indices: Vec<u32>,
}Expand description
A file that exists but has damage.
Fields
filename: Stringsize: u64damaged_block_count: u32Number of blocks in this file that are damaged.
total_block_count: u32Total blocks in this file.
damaged_block_indices: Vec<u32>Indices of the specific damaged blocks within this file (0-based).